require 'rubygems'
require 'httparty'
require_relative 'structures'

module AteTracks
  class Requests
    attr_accessor :play_token

    include HTTParty
    include Structures
    default_params format: 'jsonh'
    base_uri '8tracks.com'

    def initialize(play_token=get_play_token.content.play_token)
      @play_token = play_token
    end

    def get_play_token
      data = self.class.get('/sets/new')
      Response.new(data, 'PlayToken')
    end

    def explore_mixes(sort='popular', scope='all', include='pagination,mixes[likes_count,user,length],details')
      data = self.class.get("/explore/#{scope}/#{sort}", query: {include: include})
      Response.new(data, 'MixSet')
    end

    def mix_info(params, by_id=false)
      if by_id
        data = self.class.get("/mixes/#{params[:id]}")
      else
        data = self.class.get("/#{params[:user]}/#{params[:mix_name]}")
      end
      Response.new(data, 'Mix')
    end

    def track(mix_id, action='play', include='track[faved,annotation,artist_details]')
      data = self.class.get("/sets/#{@play_token}/#{action}", query: {include: include, mix_id: mix_id})
      Response.new(data, 'Set')
    end

    def raw_track(mix_id, action='play', include='track[faved,annotation,artist_details]')
      self.class.get("/sets/#{@play_token}/#{action}", query: {include: include, mix_id: mix_id}).body
    end
  end
end